==> owncloud-8.1.0p2.tgz: owncloud/apps/activity/l10n/gl.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Actividade",
    "Personal activity feed for %s" : "Fonte da actividade persoal para %s",
    "Your feed URL is invalid" : "O URL da fonte é incorrecto",
    "Your settings have been updated." : "Actualizaronse os axustes.",
    "This stream will show events like additions, changes & shares" : "Este fluxo amosará accións como adicións, cambios e elementos compartidos",
    "There are no events for this filter" : "Non hai actividades neste filtro",
    "Activity notification" : "Notificación da actividade",
    "All Activities" : "Todas as actividades",
    "Activities by you" : "Actividades súas",
    "Activities by others" : "Actividades doutros",
    "\"remote user\"" : "«usuario remoto»",
    "in %s" : "en %s",
    "%s and %s" : "%s e %s",
    ", " : ", ",
    "_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_" : ["%s e <strong class=\"tooltip\" title=\"%s\">%n máis</strong>","%s e <strong class=\"tooltip\" title=\"%s\">%n máis</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s e %n máis","%s e %n máis"],
    "Hello %s," : "Ola %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Recibe este correo porque na última hora sucederon as seguintes cousas en %s",
    "You are receiving this email because in the last day the following things happened at %s" : "Recibe este correo porque no último día sucederon as seguintes cousas en %s",
    "You are receiving this email because in the last week the following things happened at %s" : "Recibe este correo porque na última semana sucederon as seguintes cousas en %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* e %n máis ","* e %n máis "],
    "Notifications" : "Notificacións",
    "Mail" : "Correo",
    "Stream" : "Fluxo",
    "List your own actions in the stream" : "Listar as súas propias accións no fluxo",
    "Notify about your own actions via email" : "Notificar as súas propias accións mediante o correo",
    "You need to set up your email address before you can receive notification emails." : "É necesario estabelecer o enderezo correo para poder recibir correos de notificación.",
    "Send emails:" : "Enviar os correos:",
    "Hourly" : "Cada hora",
    "Daily" : "A diario",
    "Weekly" : "Semanalmente",
    "Activity feed" : "Fonte da actividade",
    "Enable RSS feed" : "Activar as fontes RSS",
    "No activity yet" : "Aínda non houbo actividade",
    "No more events to load" : "Non hai máis actividades para cargar",
    "Files" : "Ficheiros"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-8.2.2p3.tgz: owncloud/apps/activity/l10n/gl.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Actividade",
    "Personal activity feed for %s" : "Fonte da actividade persoal para %s",
    "Your feed URL is invalid" : "O URL da fonte é incorrecto",
    "Your settings have been updated." : "Actualizaronse os axustes.",
    "Mail" : "Correo",
    "Stream" : "Fluxo",
    "This stream will show events like additions, changes & shares" : "Este fluxo amosará accións como adicións, cambios e elementos compartidos",
    "There are no events for this filter" : "Non hai actividades neste filtro",
    "Activity notification" : "Notificación da actividade",
    "All Activities" : "Todas as actividades",
    "Activities by you" : "Actividades súas",
    "Activities by others" : "Actividades doutros",
    "\"remote user\"" : "«usuario remoto»",
    "in %s" : "en %s",
    "%s and %s" : "%s e %s",
    ", " : ", ",
    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s e <strong %s>%n máis</strong>","%s e <strong %s>%n máis</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s e %n máis","%s e %n máis"],
    "Hello %s," : "Ola %s,",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* e %n máis ","* e %n máis "],
    "Notifications" : "Notificacións",
    "List your own actions in the stream" : "Listar as súas propias accións no fluxo",
    "Notify about your own actions via email" : "Notificar as súas propias accións mediante o correo",
    "You need to set up your email address before you can receive notification emails." : "É necesario estabelecer o enderezo correo para poder recibir correos de notificación.",
    "Send emails:" : "Enviar os correos:",
    "Hourly" : "Cada hora",
    "Daily" : "A diario",
    "Weekly" : "Semanalmente",
    "Activity feed" : "Fonte da actividade",
    "Enable RSS feed" : "Activar as fontes RSS",
    "No activity yet" : "Aínda non houbo actividade",
    "No more events to load" : "Non hai máis actividades para cargar",
    "Files" : "Ficheiros",
    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s e <strong class=\"has-tooltip\" title=\"%s\">%n máis</strong>","%s e <strong class=\"has-tooltip\" title=\"%s\">%n máis</strong>"]
},
"nplurals=2; plural=(n != 1);");
